require 'simpledesktops/wallpaper'
require 'nokogiri'
require 'open-uri'

module Simpledesktops
  class Feed

    attr_reader :url

    def initialize url = default_feed
      @url = url
    end

    def list_wallpapers
      get_wallpapers
    end
    alias_method :wallpapers, :list_wallpapers

    private

    def default_feed
      "http://feeds.feedburner.com/simpledesktops?xml"
    end

    def base_url
      "http://simpledesktops.com"
    end

    def feed
      @feed ||= Nokogiri::XML open(url)
    end

    def get_wallpapers
      all_wallpapers.map do |el|
        Simpledesktops::Wallpaper.new(base_url + download_link(el)).url
      end
    end

    def all_wallpapers
      @all_wallpapers ||= feed.xpath('//item/link').map &:text
    end

    def download_link(pic)
      html = Nokogiri::HTML(open(pic))
      html.at_css('div.desktop').elements[1].children.first.attr 'href'
    end
  end
end
